@@ -562,6 +562,11 @@ ip_defrag(struct ip *iph, struct sk_buff *skb)
 				   unfragmented copy */
     return 0;
   }
+
+  /* ip_evictor() could have removed all queues for the current host */
+  if (!this_host)
+    hostfrag_create(iph);
+
   offset <<= 3;			/* offset is in 8-byte chunks */
   ihl = iph->ip_hl * 4;
 
@@ -720,6 +725,8 @@ ip_defrag_stub(struct ip *iph, struct ip **defrag)
   }
   tot_len = ntohs(iph->ip_len);
   skb = (struct sk_buff *) malloc(tot_len + sizeof(struct sk_buff));
+  if (!skb)
+      nids_params.no_mem("ip_defrag_stub");
   skb->data = (char *) (skb + 1);
   memcpy(skb->data, iph, tot_len);
   skb->truesize = tot_len + 16 + nids_params.dev_addon;
