@@ -2,7 +2,7 @@
   This file is taken from Linux 2.0.36 kernel source.
   Modified in Jun 99 by Nergal.
 */
-
+#include <config.h>
 #include <string.h>
 
 #define __u8 unsigned char
@@ -23,12 +23,10 @@
 struct timestamp {
   __u8 len;
   __u8 ptr;
-#if defined(LIBNET_LIL_ENDIAN)
-  __u8 flags:4, overflow:4;
-#elif defined(LIBNET_BIG_ENDIAN)
+#ifdef WORDS_BIGENDIAN
   __u8 overflow:4, flags:4;
 #else
-#error	"unknown byte ordering"
+  __u8 flags:4, overflow:4;
 #endif
   __u32 data[9];
 };
@@ -75,12 +73,10 @@ struct options {
 };
 
 struct iphdr {
-#if defined(LIBNET_LIL_ENDIAN)
-  __u8 ihl:4, version:4;
-#elif defined (LIBNET_BIG_ENDIAN)
+#ifdef WORDS_BIGENDIAN
   __u8 version:4, ihl:4;
 #else
-#error	"unknown byte ordering"
+  __u8 ihl:4, version:4;
 #endif
   __u8 tos;
   __u16 tot_len;
