@@ -33,17 +33,25 @@ gettime()
 }
 
 void
-scan_init()
+scan_init(void)
 {
   struct timeval tv;
 
   if (nids_params.scan_num_hosts > 0) {
     gettimeofday(&tv, 0);
     time0 = tv.tv_sec;
-    hashhost = (struct host **) malloc(sizeof(struct host *) * nids_params.scan_num_hosts);
+    hashhost = (struct host **) calloc(nids_params.scan_num_hosts, sizeof(struct host *));
     if (!hashhost)
       nids_params.no_mem("scan_init");
-    memset(hashhost, 0, sizeof(struct host *) * nids_params.scan_num_hosts);
+  }
+}
+
+void
+scan_exit(void)
+{
+  if (hashhost) {
+    free(hashhost);
+    hashhost = NULL;
   }
 }
 
