@@ -2,9 +2,9 @@
   Copyright (c) 1999 Rafal Wojtczuk <nergal@avet.com.pl>. All rights reserved.
   See the file COPYING for license details.
 */
-
 #ifndef _NIDS_TCP_H
 #define _NIDS_TCP_H
+#include <sys/time.h>
 
 struct skbuff {
   struct skbuff *next;
@@ -22,8 +22,9 @@ struct skbuff {
 };
 
 int tcp_init(int);
+void tcp_exit(void);
 void process_tcp(u_char *, int);
 void process_icmp(u_char *);
-void clear_stream_buffers();
+void tcp_check_timeouts(struct timeval *);
 
 #endif /* _NIDS_TCP_H */
