@@ -25,5 +25,7 @@ void nids_no_mem(char *);
 char *test_malloc(int);
 inline int before(u_int seq1, u_int seq2);
 inline int after(u_int seq1, u_int seq2);
+void register_callback(struct proc_node **procs, void (*x));
+void unregister_callback(struct proc_node **procs, void (*x));
 
 #endif /* _NIDS_UTIL_H */
